//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Device/InputOutput/ReadWriteNumpyTXT.h
//! @brief     Defines ReadWriteNumpyTXT
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifdef SWIG
#error no need to expose this header to Swig
#endif

#ifndef USER_API
#ifndef BORNAGAIN_DEVICE_INPUTOUTPUT_READWRITENUMPYTXT_H
#define BORNAGAIN_DEVICE_INPUTOUTPUT_READWRITENUMPYTXT_H

#include <istream>

template <class T>
class Powerfield;

//! Class for reading and writing Powerfield from simple ASCII file with the layout as in
//! numpy.savetxt.

class ReadWriteNumpyTXT {
public:
    Powerfield<double>* readPowerfield(std::istream& input_stream);
    void writePowerfield(const Powerfield<double>& data, std::ostream& output_stream);

private:
    static void write1DRepresentation(const Powerfield<double>& data, std::ostream& output_stream);
    static void write2DRepresentation(const Powerfield<double>& data, std::ostream& output_stream);
    static double ignoreDenormalized(double value);
};

#endif // BORNAGAIN_DEVICE_INPUTOUTPUT_READWRITENUMPYTXT_H
#endif // USER_API
