//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Project/IOService.h
//! @brief     Defines class PowerfieldIOService
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_PROJECT_IOSERVICE_H
#define BORNAGAIN_GUI_MODEL_PROJECT_IOSERVICE_H

#include "GUI/Support/IO/IOHistory.h"
#include <QObject>

class ApplicationModels;
class MessageService;
class SaveLoadInterface;

//! Provide read/write of heavy data files in a separate thread.
//!
//! Listens all models and keep tracks of changes in items. Provides logic to
//! not to re-save already saved data.

class PowerfieldIOService : public QObject {
    Q_OBJECT
public:
    explicit PowerfieldIOService(QObject* parent = nullptr);
    explicit PowerfieldIOService(ApplicationModels* models, QObject* parent = nullptr);

    void setApplicationModels(ApplicationModels* models);

    void save(const QString& projectDir);

    void loadDataFiles(const QString& projectDir, MessageService* messageService = nullptr);

    QVector<SaveLoadInterface*> dataInterfaces() const;

private:
    void cleanOldFiles(const QString& projectDir, const QStringList& oldSaves,
                       const QStringList& newSaves);

    PowerfieldIOHistory m_history;
    ApplicationModels* m_applicationModels;
};

#endif // BORNAGAIN_GUI_MODEL_PROJECT_IOSERVICE_H
