//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Support/IO/IOUtils.cpp
//! @brief     Implements PowerfieldUtils namespace
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Support/IO/IOUtils.h"
#include "Device/Data/Powerfield.h"

std::unique_ptr<Powerfield<double>> GUI::Util::IO::binifyAxes(const Powerfield<double>& data)
{
    std::unique_ptr<Powerfield<double>> result(new Powerfield<double>);
    for (size_t i = 0; i < data.rank(); ++i) {
        const IAxis& axis = data.axis(i);
        result->addAxis(FixedBinAxis(axis.axisName(), axis.size(), 0., axis.size()));
    }
    result->setRawDataVector(data.getRawDataVector());

    return result;
}
