//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Fit/MinimizerSettingsWidget.h
//! @brief     Defines class MinimizerSettingsWidget
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_FIT_MINIMIZERSETTINGSWIDGET_H
#define BORNAGAIN_GUI_VIEW_FIT_MINIMIZERSETTINGSWIDGET_H

#include "GUI/Model/Descriptor/SelectionDescriptor.h"
#include <QList>
#include <QWidget>
#include <functional>

class JobItem;
class MinimizerContainerItem;
class DoubleDescriptor;
class UIntDescriptor;
class QFormLayout;

using std::function;

//! The MinimizerSettingsWidget contains editor for all minimizer settings and related fit
//! options. Part of FitSuiteWidget.

class MinimizerSettingsWidget : public QWidget {
    Q_OBJECT

public:
    MinimizerSettingsWidget(QWidget* parent = nullptr);

public slots:
    void setItem(JobItem* jobItem);
    void setItem(MinimizerContainerItem* minimizerItem);

private:
    QWidget* createComboBox(SelectionDescriptor<QString> d);
    QWidget* createDoubleSpinbox(DoubleDescriptor d);
    QWidget* createSpinbox(UIntDescriptor d);
    void createMimimizerEdits();

    void updateUIValues();


private:
    MinimizerContainerItem* m_currentItem;
    QFormLayout* m_mainLayout;
    QFormLayout* m_minimizerLayout;
    QList<function<void()>> m_updaters;
};

#endif // BORNAGAIN_GUI_VIEW_FIT_MINIMIZERSETTINGSWIDGET_H
