//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/PropertyEditor/SpecularDataPropertyWidget.h
//! @brief     Defines class SpecularDataPropertyWidget
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_PROPERTYEDITOR_SPECULARDATAPROPERTYWIDGET_H
#define BORNAGAIN_GUI_VIEW_PROPERTYEDITOR_SPECULARDATAPROPERTYWIDGET_H

#include "GUI/Model/Descriptor/SelectionDescriptor.h"
#include <QList>
#include <QString>
#include <QWidget>
#include <functional>

class SpecularDataItem;
class SessionItem;
class QFormLayout;
class DoubleDescriptor;
class Data1DViewItem;

using std::function;

//! Widget to edit properties of a SpecularDataItem or a Data1DViewItem.

class SpecularDataPropertyWidget : public QWidget {
    Q_OBJECT
public:
    explicit SpecularDataPropertyWidget(QWidget* parent = nullptr);

    void setItem(SpecularDataItem* item);
    void setItem(Data1DViewItem* item);

private:
    QWidget* createDoubleSpinbox(DoubleDescriptor d);
    QWidget* createTextEdit(SessionItem* item);
    QWidget* createCheckBox(const QString& title, SessionItem* item);
    QWidget* createCheckBox(const QString& title, function<bool()> getter,
                            function<void(bool)> setter);
    QWidget* createComboBox(SelectionDescriptor<QString> d);

    void updateUIValues();
    void setCurrentItem(SessionItem* item);

private:
    SessionItem* m_item;
    QFormLayout* m_mainLayout;
    QList<function<void()>> m_updaters;
};

#endif // BORNAGAIN_GUI_VIEW_PROPERTYEDITOR_SPECULARDATAPROPERTYWIDGET_H
