//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Resample/Coherence/CoherentFFSum.cpp
//! @brief     Implements class CoherentFFSum.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "Resample/Coherence/CoherentFFSum.h"
#include "Resample/Coherence/SumDWBA.h"
#include "Resample/Particle/IReParticle.h"
#include <utility>

CoherentFFSum::CoherentFFSum(double abundance, std::vector<std::shared_ptr<const SumDWBA>> terms)
    : m_abundance(abundance)
    , m_terms(std::move(terms))
{
}

complex_t CoherentFFSum::summedFF(const DiffuseElement& ele) const
{
    complex_t result = 0.;
    for (const auto& term : m_terms)
        result += term->coherentFF(ele);
    return result;
}

SpinMatrix CoherentFFSum::summedPolFF(const DiffuseElement& ele) const
{
    SpinMatrix result;
    for (const auto& term : m_terms)
        result += term->coherentPolFF(ele);
    return result;
}

double CoherentFFSum::radialExtension() const
{
    return m_terms[0]->ff().radialExtension();
}
