//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sample/HardParticle/CantellatedCube.h
//! @brief     Defines class CantellatedCube.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_SAMPLE_HARDPARTICLE_CANTELLATEDCUBE_H
#define BORNAGAIN_SAMPLE_HARDPARTICLE_CANTELLATEDCUBE_H

#include "Sample/HardParticle/IFormFactorPolyhedron.h"

//! A cube, with truncation of all edges and corners, as in Croset (2017) Fig 7
//! @ingroup hardParticle

class CantellatedCube : public IFormFactorPolyhedron {
public:
    CantellatedCube(double length, double removed_length);
#ifndef USER_API
    CantellatedCube(std::vector<double> P);

    CantellatedCube* clone() const override
    {
        return new CantellatedCube(m_length, m_removed_length);
    }
    std::string className() const final { return "CantellatedCube"; }
    // const auto tooltip = "a cube with truncated edges and vertices";
    std::vector<ParaMeta> parDefs() const final
    {
        return {{"Length", "nm", "length of untruncated edge", 0, +INF, 0},
                {"RemovedLength", "nm",
                 "side length of the trirectangular tetrahedron removed one corner", 0, +INF, 0}};
    }

    double length() const { return m_length; }
    double removedLength() const { return m_removed_length; }
#endif // USER_API

private:
    static const ff::PolyhedralTopology topology;
    const double& m_length;
    const double& m_removed_length;
};

#endif // BORNAGAIN_SAMPLE_HARDPARTICLE_CANTELLATEDCUBE_H
