//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sample/HardParticle/HollowSphere.h
//! @brief     Defines class HollowSphere.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_SAMPLE_HARDPARTICLE_HOLLOWSPHERE_H
#define BORNAGAIN_SAMPLE_HARDPARTICLE_HOLLOWSPHERE_H

#include "Sample/HardParticle/FullSphere.h"

//! Integrated full sphere form factor over a uniform distribution of radii.
//! @ingroup softParticle

class HollowSphere : public IFormFactor {
public:
    HollowSphere(double mean, double full_width);
#ifndef USER_API
    HollowSphere(std::vector<double> P);

    HollowSphere* clone() const override { return new HollowSphere(m_mean, m_full_width); }
    std::string className() const final { return "HollowSphere"; }
    // const auto tooltip = "class_tooltip";
    std::vector<ParaMeta> parDefs() const final
    {
        return {{"MeanRadius", "nm", "para_tooltip", 0, +INF, 0},
                {"FullWidth", "nm", "para_tooltip", 0, +INF, 0}};
    }

    double radialExtension() const override { return m_mean; }

    complex_t formfactor_at_bottom(C3 q) const override;

private:
    bool checkParameters() const;
    const double& m_mean;       //!< This is the mean radius
    const double& m_full_width; //!< This is the full width of the radius distribution
#endif                          // USER_API
};

#endif // BORNAGAIN_SAMPLE_HARDPARTICLE_HOLLOWSPHERE_H
