#include "Device/Histo/SimulationResult.h"
#include "Base/Const/Units.h"
#include "Device/Beam/Beam.h"
#include "Device/Coord/CoordSystem2D.h"
#include "Device/Data/Powerfield.h"
#include "Device/Detector/SphericalDetector.h"
#include "Tests/GTestWrapper/google_test.h"

class SimulationResultTest : public ::testing::Test {
};

TEST_F(SimulationResultTest, max)
{
    Powerfield<double> data;
    data.addAxis("axis1", 10, 0., 10.);
    data.addAxis("axis2", 2, 0., 10.);
    Powerfield<double>::iterator it = data.begin();
    for (size_t i = 0; i < data.getAllocatedSize(); ++i)
        if (i == 10)
            (*it) = 10.0;

    SphericalDetector det(100, 0.0, 5.0 * Units::deg, 70, -2.0 * Units::deg, 1.5);
    Beam beam(1.0, 1.0, {1 * Units::deg, 0});
    SphericalCoords coords(det.axesClippedToRegionOfInterest(), beam.direction(),
                           beam.wavelength());

    SimulationResult sr1(data, coords.clone());

    SimulationResult sr2 = sr1.relativeToMaximum();

    EXPECT_EQ(sr2.max(), 1.);
}
