#include "GUI/Model/Model/SessionModel.h"
#include "GUI/Support/Type/VariantUtil.h"
#include "GUI/Util/ComboProperty.h"
#include "Tests/GTestWrapper/google_test.h"

class TestSessionItemUtils : public ::testing::Test {
};

//! Comparing types of variant.

TEST_F(TestSessionItemUtils, VariantType)
{
    EXPECT_TRUE(GUI::Util::Variant::VariantType(QVariant::fromValue(1.0))
                == GUI::Util::Variant::VariantType(QVariant::fromValue(2.0)));
    EXPECT_FALSE(GUI::Util::Variant::VariantType(QVariant::fromValue(1.0))
                 == GUI::Util::Variant::VariantType(QVariant::fromValue(1)));
    EXPECT_FALSE(GUI::Util::Variant::VariantType(QVariant::fromValue(1.0))
                 == GUI::Util::Variant::VariantType(QVariant::fromValue(QString{"a"})));

    QVariant v1, v2;
    EXPECT_TRUE(GUI::Util::Variant::VariantType(v1) == GUI::Util::Variant::VariantType(v2));
    EXPECT_FALSE(GUI::Util::Variant::VariantType(v1)
                 == GUI::Util::Variant::VariantType(QVariant::fromValue(42.0)));

    ComboProperty c1, c2;
    EXPECT_TRUE(GUI::Util::Variant::VariantType(c1.variant())
                == GUI::Util::Variant::VariantType(c2.variant()));
    EXPECT_FALSE(GUI::Util::Variant::VariantType(c1.variant())
                 == GUI::Util::Variant::VariantType(QVariant::fromValue(42.0)));
    EXPECT_FALSE(GUI::Util::Variant::VariantType(c1.variant())
                 == GUI::Util::Variant::VariantType(QVariant()));
}

//! Comparing types of variant.

TEST_F(TestSessionItemUtils, CompatibleVariantTypes)
{
    QVariant undefined;
    QVariant comboProperty = QVariant::fromValue(ComboProperty());
    QVariant doubleProperty = QVariant::fromValue(42.0);

    EXPECT_TRUE(GUI::Util::Variant::CompatibleVariantTypes(undefined, comboProperty));
    EXPECT_TRUE(GUI::Util::Variant::CompatibleVariantTypes(undefined, doubleProperty));

    EXPECT_TRUE(GUI::Util::Variant::CompatibleVariantTypes(comboProperty, comboProperty));
    EXPECT_TRUE(GUI::Util::Variant::CompatibleVariantTypes(doubleProperty, doubleProperty));

    EXPECT_FALSE(GUI::Util::Variant::CompatibleVariantTypes(doubleProperty, comboProperty));
    EXPECT_FALSE(GUI::Util::Variant::CompatibleVariantTypes(comboProperty, doubleProperty));
}

//! Test variant equality reported by GUI::Util::Variant::isTheSame

TEST_F(TestSessionItemUtils, IsTheSameVariant)
{
    // comparing undefined variants
    QVariant v1, v2;
    EXPECT_TRUE(GUI::Util::Variant::IsTheSame(v1, v2));

    // comparing QVariant based on double
    EXPECT_TRUE(GUI::Util::Variant::IsTheSame(QVariant::fromValue(1.0), QVariant::fromValue(1.0)));
    EXPECT_FALSE(GUI::Util::Variant::IsTheSame(QVariant::fromValue(1.0), QVariant::fromValue(2.0)));

    // comparing QVariant based on strings
    EXPECT_TRUE(GUI::Util::Variant::IsTheSame(QVariant::fromValue(QString{"a"}),
                                              QVariant::fromValue(QString{"a"})));
    EXPECT_FALSE(GUI::Util::Variant::IsTheSame(QVariant::fromValue(QString{"a"}),
                                               QVariant::fromValue(QString{"b"})));

    // comparing variants of different type
    EXPECT_FALSE(GUI::Util::Variant::IsTheSame(QVariant::fromValue(1.0), QVariant::fromValue(1)));

    ComboProperty c1, c2;
    EXPECT_FALSE(GUI::Util::Variant::IsTheSame(c1.variant(), c2.variant()));
    EXPECT_FALSE(GUI::Util::Variant::IsTheSame(c1.variant(), QVariant::fromValue(42.0)));
}
