"""
BornAgain collection of standard simulation setups.
"""
import bornagain as ba
from bornagain import deg, angstrom


def specular(sample, scan_size):
    """
    Returns a standard specular simulation.
    """
    simulation = ba.SpecularSimulation()
    scan = ba.AlphaScan(1.54*angstrom, scan_size, 0, 2*deg)
    simulation.setScan(scan)
    simulation.setSample(sample)
    return simulation


def sas(sample, npix):
    """
    Returns a standard simulation in small-angle scattering geometry.
    Incident beam is almost horizontal.
    """
    beam = ba.Beam(1, 1*angstrom, ba.Direction(1e-8*deg, 0))
    det = ba.SphericalDetector(npix, 10*deg, 0, 0)
    return ba.ScatteringSimulation(beam, sample, det)
